@@ -56,6 +56,7 @@ logging_config = {
             "filters": ["hostname", "source_ip", "concurrent_id"]
         },
         "file": {
+            'level': 'INFO',
             "class": "logging.handlers.TimedRotatingFileHandler",
             "filename": os.path.join(log_dir, "log.log"),
             "formatter": "winhye",
@@ -63,14 +64,19 @@ logging_config = {
             "when": "H",
             "interval": 1,
             "backupCount": 168,
-            "atTime": datetime.datetime.now(),
-            "delay": False
-        }
+        },
+        'watch_handler': {
+            'level': 1000,
+            'filename': os.path.join(log_dir, "log.log"),
+            'class': 'logging.handlers.WatchedFileHandler',
+            'formatter': 'winhye'
+        },
     },
     "loggers": {
         "": {
-            "level": "DEBUG",  # logger日志输出级别
-            "handlers": ["console", "file"],
+            "level": "INFO",  # logger日志输出级别
+            "handlers": ["console", "file", "watch_handler"],
+            'propagate': True
         },
         "gunicorn.error": {
             "level": "INFO",
